@@ -124,13 +124,13 @@ sub 𝝿 {4*atan2(1,1)}
 # Length of a vector
 #-------------------------------------------------------------------------------
 
-sub vectorSquaredLength($$;$$)                                                  # Length of a vector or distance betwee two vectors squared - useful for finding out which is longest withiout having to take a square root
+sub vectorSquaredLength($$;$$)                                                  # Length of a vector or distance between two vectors squared - useful for finding out which is longest without having to take a square root
  {my ($x, $y, $𝘅, $𝘆) = @_;
   my $r = ($x-($𝘅//0))**2+($y-($𝘆//0))**2;
   $r
  }
 
-sub vectorLength($$;$$) {sqrt(&vectorSquaredLength(@_))}                        # Length of a vector or distance betwee two vectors
+sub vectorLength($$;$$) {sqrt(&vectorSquaredLength(@_))}                        # Length of a vector or distance between two vectors
 
 #-------------------------------------------------------------------------------
 # Lengths of the sides of a polygon
@@ -152,17 +152,17 @@ sub lengthsOfTheSidesOfAPolygon($$@)
  }
 
 #-------------------------------------------------------------------------------
-# Check whether three points are close to colinear by the Schwartz inequality
+# Check whether three points are close to collinear by the Schwartz inequality
 #-------------------------------------------------------------------------------
 
-sub threeColinearPoints($$$$$$)                                                 # Three points to be tested
+sub threeCollinearPoints($$$$$$)                                                # Three points to be tested
  {my ($x, $y, $𝘅, $𝘆, $𝕩, $𝕪) = @_;
   @_ == 6 or confess "Wrong number of parameters";
-  return 1 if near($x, $𝘅) && near($y, $𝘆) or near($x, $𝕩) && near($y, $𝕪);     # When two points are close the points are effectively colinear - although we should really check that all three points are not close sa this would identify either a number representation problem or a bad definition of nearness for this application
+  return 1 if near($x, $𝘅) && near($y, $𝘆) or near($x, $𝕩) && near($y, $𝕪);     # When two points are close the points are effectively collinear - although we should really check that all three points are not close sa this would identify either a number representation problem or a bad definition of nearness for this application
   my $d = vectorLength($𝘅, $𝘆, $𝕩, $𝕪);
   my $𝗱 = vectorLength($x, $y, $𝕩, $𝕪);                                         # Lengths of sides opposite corners
   my $𝕕 = vectorLength($x, $y, $𝘅, $𝘆);
-  return 1 if near($d, $𝗱) && near($𝕕);                                         # Two sides equal and the other small makes the lines effectively colinear
+  return 1 if near($d, $𝗱) && near($𝕕);                                         # Two sides equal and the other small makes the lines effectively collinear
   return 1 if near($d, $𝕕) && near($𝗱);
   return 1 if near($𝗱, $𝕕) && near($d);
   near($d, $𝗱+$𝕕) or near($𝗱, $𝕕+$d) or near($𝕕, $d+$𝗱)                         # One side is almost as long as the other two combined
@@ -300,14 +300,14 @@ sub intersectionLinePoint(&$$$$$$)
   return &$sub($x, $y) if near($x, $𝘅) && near($y, $𝘆) or                       # Point in question is near an end of the line segment
                           near($x, $𝕩) && near($y, $𝕪);
 
-  return &$sub($x, $y) if threeColinearPoints($𝘅, $𝘆, $𝕩, $𝕪, $x, $y);          # Colinear
-                                                                                # Points known not to be colinear
+  return &$sub($x, $y) if threeCollinearPoints($𝘅, $𝘆, $𝕩, $𝕪, $x, $y);         # Collinear
+                                                                                # Points known not to be collinear
   my $𝗿 = vectorLength($𝘅 - $x, $𝘆 - $y);                                       # Radius of first circle
   my $𝕣 = vectorLength($𝕩 - $x, $𝕪 - $y);                                       # Radius of second circle
   intersectionCircles
    {return &$sub(@_) if @_ == 2;                                                # Point is on line
     my ($x, $y, $𝘅, $𝘆) = @_;
-    &$sub(($x+$𝘅) / 2, ($y+$𝘆) / 2)                                             # Average intersection of intersection [poins
+    &$sub(($x+$𝘅) / 2, ($y+$𝘆) / 2)                                             # Average intersection of intersection points
    } $𝘅, $𝘆, $𝗿, $𝕩, $𝕪, $𝕣;
  }
 
@@ -343,9 +343,9 @@ sub intersectionLines(&$$$$$$$$)
     intersectionLinePoint                                                       # Find 𝗯
      {my ($𝗯x, $𝗯y) = @_;
       my $La = vectorSquaredLength($𝗫 - $𝗮x, $𝗬 - $𝗮y);                         # Squared distance from 𝗟 to 𝗮
-      return &$sub($𝗫, $𝗬) if near($La);                                        # End point of second line is on first line bu the lines are not parallel
+      return &$sub($𝗫, $𝗬) if near($La);                                        # End point of second line is on first line but the lines are not parallel
       my $Lb = vectorSquaredLength($𝗫 - $𝗯x, $𝗬 - $𝗯y);                         # Squared distance from 𝗟 to 𝗯
-      near($Lb) and confess "Parallel lines!";                                  # Although this shoul not happen as we have a;ready checked that the lines are not parallel
+      near($Lb) and confess "Parallel lines!";                                  # Although this should not happen as we have already checked that the lines are not parallel
       my $s  = $La / $Lb;                                                       # Scale factor for 𝗟𝗯
       &$sub($𝗫 + $s * ($𝗯x - $𝗫), $𝗬 + $s * ($𝗯y - $𝗬))                         # Point of intersection
      } $𝗫,$𝗬,  $𝕏,$𝕐,  $𝗮x,$𝗮y;                                                 # Find 𝗯 on second line
@@ -451,7 +451,7 @@ sub circumCircle(&$$$$$$)
 
   circumCentre
    {my ($X, $Y) = @_;                                                           # Centre
-    my @r = (vectorLength($x, $y, $X, $Y),                                      # Radiii
+    my @r = (vectorLength($x, $y, $X, $Y),                                      # Radii
              vectorLength($𝘅, $𝘆, $X, $Y),
              vectorLength($𝕩, $𝕪, $X, $Y));
     &near(@r[0,1]) && &near(@r[1,2]) or confess "Bad radius computed!";
@@ -547,7 +547,7 @@ sub orthoCentre(&$$$$$$)
 sub areaOfTriangle(&$$$$$$)
  {my ($sub, $x, $y, $𝘅, $𝘆, $𝕩, $𝕪) = @_;                                       # Subroutine to process results, coordinates of corners
   @_ == 7 or confess "Wrong number of parameters";
-  return &$sub(0) if near($x, $𝘅) && near($y, $𝘆) or near($𝘅, $𝕩) && near($𝘆, $𝕪); # A pair of corners are close, so the arae of the triangle must be zero
+  return &$sub(0) if near($x, $𝘅) && near($y, $𝘆) or near($𝘅, $𝕩) && near($𝘆, $𝕪); # A pair of corners are close, so the area of the triangle must be zero
   my ($d) = unsignedDistanceFromLineToPoint(sub {@_}, $𝘅, $𝘆, $𝕩, $𝕪, $x, $y);  # Distance for first corner from opposite line
   &$sub($d * vectorLength($𝘅, $𝘆, $𝕩, $𝕪)/2)                                    # Area = half base * height
  }
@@ -564,8 +564,8 @@ sub areaOfPolygon(&@)
   my ($area) = areaOfTriangle {@_} $x, $y, $𝘅, $𝘆, $𝕩, $𝕪;                      # Area of first triangle
   for(;scalar @vertices;)                                                       # Each subsequent triangle
    {($𝘅, $𝘆) = ($𝕩, $𝕪);                                                        # Move up one vertex at a time
-    ($𝕩, $𝕪) = splice @vertices, 0, 2;                                          # Remove one vetex
-    my ($a) = areaOfTriangle {@_} $x, $y, $𝘅, $𝘆, $𝕩, $𝕪;                       # Area of lastest triangle
+    ($𝕩, $𝕪) = splice @vertices, 0, 2;                                          # Remove one vertex
+    my ($a) = areaOfTriangle {@_} $x, $y, $𝘅, $𝘆, $𝕩, $𝕪;                       # Area of latest triangle
     $area += $a;                                                                # Sum areas
    }
   &$sub($area)                                                                  # Area of polygon
@@ -610,19 +610,6 @@ sub isRightAngledTriangle(@)
   near($d**2,$𝗱**2+$𝕕**2)||near($𝗱**2,$d**2+$𝕕**2) || near($𝕕**2,$d**2+$𝗱**2)   # Pythagoras
  }
 
-
-# Euler Line, see: https://en.wikipedia.org/wiki/Euler_line
-
-if (1)
- {my @t = (0, 0, 4, 0, 0, 3);                                                   # Corners of the triangle
-  &areaOfPolygon(sub {say @_;},                                                 # Polygon formed by these points has zero area and so is a line or a point
-    &circumCircle   (sub {@_[0,1]}, @t),                                        # green
-    &ninePointCircle(sub {@_[0,1]}, @t),                                        # red
-    &orthoCentre    (sub {@_[0,1]}, @t),                                        # blue
-    &centroid       (sub {@_[0,1]}, @t));                                       # orange
- }
-
-
 #-------------------------------------------------------------------------------
 # 𝗘xport details
 #-------------------------------------------------------------------------------
@@ -642,11 +629,11 @@ centroid isEquilateralTriangle isIsoscelesTriangle isRightAngledTriangle);
 
 @EXPORT_OK = qw(midPoint near near2 near3 near4 rotate90CW rotate90CCW
 rotate90AroundMidPoint vectorLength 𝝿 lengthsOfTheSidesOfAPolygon
-threeColinearPoints);
+threeCollinearPoints);
 
 $EXPORT_TAGS{all} = [@EXPORT, @EXPORT_OK];
 #$VERSION  = '1.003'; # Sunday 30 Aug 2015 - started Geometry app
-$VERSION   = '1.004'; # Sunday 20 Dec 2015 - still going!
+$VERSION   = '1.005'; # Sunday 20 Dec 2015 - still going!
 
 =head1 Description
 
@@ -668,7 +655,7 @@ $VERSION   = '1.004'; # Sunday 20 Dec 2015 - still going!
 
 =head2 areaOfPolygon sub points...
 
- Calls sub($a) where $a is the area of the polygon with vertoces specified by
+ Calls sub($a) where $a is the area of the polygon with vertices specified by
  the point.
 
  A point is specified by supplying a list of two numbers:
@@ -706,7 +693,7 @@ $VERSION   = '1.004'; # Sunday 20 Dec 2015 - still going!
 
 =head2 circumCircle sub triangle
 
- Calls sub($x,$y,$r) where $x,$y are the coordinates of the circum centre of
+ Calls sub($x,$y,$r) where $x,$y are the coordinates of the circum-centre of
  the specified triangle and $r is its radius:
 
  See: https://en.wikipedia.org/wiki/Circumscribed_circle
@@ -905,7 +892,7 @@ $VERSION   = '1.004'; # Sunday 20 Dec 2015 - still going!
 
 =head2 orthoCentre sub triangle
 
- Calls sub($x,$y) where $x,$y are the coordinates of the ortho centre of the
+ Calls sub($x,$y) where $x,$y are the coordinates of the ortho-centre of the
  specified triangle:
 
  See: https://en.wikipedia.org/wiki/Altitude_%28triangle%29
@@ -992,7 +979,7 @@ $VERSION   = '1.004'; # Sunday 20 Dec 2015 - still going!
 
 =item C<rotate90AroundMidPoint()>
 
-=item C<threeColinearPoints()>
+=item C<threeCollinearPoints()>
 
 =item C<vectorLength()>
 
